@@ -11,43 +11,43 @@
 # limitations under the License.
 
 import fixtures
-import itertools
 import os
 import requests
 import sys
-import tarfile
-import tempfile
 from unittest import mock
 
 from kolla.cmd import build as build_cmd
 from kolla.image import build
+from kolla.image.kolla_worker import Image
+from kolla.image import tasks
+from kolla.image import utils
 from kolla.tests import base
 
 
-FAKE_IMAGE = build.Image(
+FAKE_IMAGE = Image(
     'image-base', 'image-base:latest',
     '/fake/path', parent_name=None,
-    parent=None, status=build.Status.MATCHED)
-FAKE_IMAGE_CHILD = build.Image(
+    parent=None, status=utils.Status.MATCHED)
+FAKE_IMAGE_CHILD = Image(
     'image-child', 'image-child:latest',
     '/fake/path2', parent_name='image-base',
-    parent=FAKE_IMAGE, status=build.Status.MATCHED)
-FAKE_IMAGE_CHILD_UNMATCHED = build.Image(
+    parent=FAKE_IMAGE, status=utils.Status.MATCHED)
+FAKE_IMAGE_CHILD_UNMATCHED = Image(
     'image-child-unmatched', 'image-child-unmatched:latest',
     '/fake/path3', parent_name='image-base',
-    parent=FAKE_IMAGE, status=build.Status.UNMATCHED)
-FAKE_IMAGE_CHILD_ERROR = build.Image(
+    parent=FAKE_IMAGE, status=utils.Status.UNMATCHED)
+FAKE_IMAGE_CHILD_ERROR = Image(
     'image-child-error', 'image-child-error:latest',
     '/fake/path4', parent_name='image-base',
-    parent=FAKE_IMAGE, status=build.Status.ERROR)
-FAKE_IMAGE_CHILD_BUILT = build.Image(
+    parent=FAKE_IMAGE, status=utils.Status.ERROR)
+FAKE_IMAGE_CHILD_BUILT = Image(
     'image-child-built', 'image-child-built:latest',
     '/fake/path5', parent_name='image-base',
-    parent=FAKE_IMAGE, status=build.Status.BUILT)
-FAKE_IMAGE_GRANDCHILD = build.Image(
+    parent=FAKE_IMAGE, status=utils.Status.BUILT)
+FAKE_IMAGE_GRANDCHILD = Image(
     'image-grandchild', 'image-grandchild:latest',
     '/fake/path6', parent_name='image-child',
-    parent=FAKE_IMAGE_CHILD, status=build.Status.MATCHED)
+    parent=FAKE_IMAGE_CHILD, status=utils.Status.MATCHED)
 
 
 class TasksTest(base.TestCase):
@@ -62,64 +62,49 @@ class TasksTest(base.TestCase):
         self.imageChild.parent = self.image
         self.imageChild.path = self.useFixture(fixtures.TempDir()).path
 
-    @mock.patch('docker.version', '2.7.0')
-    @mock.patch.dict(os.environ, clear=True)
-    @mock.patch('docker.APIClient')
-    def test_push_image_before_v3_0_0(self, mock_client):
-        self.dc = mock_client
-        pusher = build.PushTask(self.conf, self.image)
-        pusher.run()
-        mock_client().push.assert_called_once_with(
-            self.image.canonical_name, decode=True,
-            stream=True, insecure_registry=True)
-
-    @mock.patch('docker.version', '3.0.0')
     @mock.patch.dict(os.environ, clear=True)
     @mock.patch('docker.APIClient')
     def test_push_image(self, mock_client):
         self.dc = mock_client
-        pusher = build.PushTask(self.conf, self.image)
+        pusher = tasks.PushTask(self.conf, self.image)
         pusher.run()
         mock_client().push.assert_called_once_with(
             self.image.canonical_name, decode=True, stream=True)
         self.assertTrue(pusher.success)
 
-    @mock.patch('docker.version', '3.0.0')
     @mock.patch.dict(os.environ, clear=True)
     @mock.patch('docker.APIClient')
     def test_push_image_failure(self, mock_client):
         """failure on connecting Docker API"""
         self.dc = mock_client
         mock_client().push.side_effect = Exception
-        pusher = build.PushTask(self.conf, self.image)
+        pusher = tasks.PushTask(self.conf, self.image)
         pusher.run()
         mock_client().push.assert_called_once_with(
             self.image.canonical_name, decode=True, stream=True)
         self.assertFalse(pusher.success)
-        self.assertEqual(build.Status.PUSH_ERROR, self.image.status)
+        self.assertEqual(utils.Status.PUSH_ERROR, self.image.status)
 
-    @mock.patch('docker.version', '3.0.0')
     @mock.patch.dict(os.environ, clear=True)
     @mock.patch('docker.APIClient')
     def test_push_image_failure_retry(self, mock_client):
         """failure on connecting Docker API, success on retry"""
         self.dc = mock_client
         mock_client().push.side_effect = [Exception, []]
-        pusher = build.PushTask(self.conf, self.image)
+        pusher = tasks.PushTask(self.conf, self.image)
         pusher.run()
         mock_client().push.assert_called_once_with(
             self.image.canonical_name, decode=True, stream=True)
         self.assertFalse(pusher.success)
-        self.assertEqual(build.Status.PUSH_ERROR, self.image.status)
+        self.assertEqual(utils.Status.PUSH_ERROR, self.image.status)
 
         # Try again, this time without exception.
         pusher.reset()
         pusher.run()
         self.assertEqual(2, mock_client().push.call_count)
         self.assertTrue(pusher.success)
-        self.assertEqual(build.Status.BUILT, self.image.status)
+        self.assertEqual(utils.Status.BUILT, self.image.status)
 
-    @mock.patch('docker.version', '3.0.0')
     @mock.patch.dict(os.environ, clear=True)
     @mock.patch('docker.APIClient')
     def test_push_image_failure_error(self, mock_client):
@@ -127,14 +112,13 @@ class TasksTest(base.TestCase):
         self.dc = mock_client
         mock_client().push.return_value = [{'errorDetail': {'message':
                                                             'mock push fail'}}]
-        pusher = build.PushTask(self.conf, self.image)
+        pusher = tasks.PushTask(self.conf, self.image)
         pusher.run()
         mock_client().push.assert_called_once_with(
             self.image.canonical_name, decode=True, stream=True)
         self.assertFalse(pusher.success)
-        self.assertEqual(build.Status.PUSH_ERROR, self.image.status)
+        self.assertEqual(utils.Status.PUSH_ERROR, self.image.status)
 
-    @mock.patch('docker.version', '3.0.0')
     @mock.patch.dict(os.environ, clear=True)
     @mock.patch('docker.APIClient')
     def test_push_image_failure_error_retry(self, mock_client):
@@ -142,12 +126,12 @@ class TasksTest(base.TestCase):
         self.dc = mock_client
         mock_client().push.return_value = [{'errorDetail': {'message':
                                                             'mock push fail'}}]
-        pusher = build.PushTask(self.conf, self.image)
+        pusher = tasks.PushTask(self.conf, self.image)
         pusher.run()
         mock_client().push.assert_called_once_with(
             self.image.canonical_name, decode=True, stream=True)
         self.assertFalse(pusher.success)
-        self.assertEqual(build.Status.PUSH_ERROR, self.image.status)
+        self.assertEqual(utils.Status.PUSH_ERROR, self.image.status)
 
         # Try again, this time without exception.
         mock_client().push.return_value = [{'stream': 'mock push passes'}]
@@ -155,14 +139,14 @@ class TasksTest(base.TestCase):
         pusher.run()
         self.assertEqual(2, mock_client().push.call_count)
         self.assertTrue(pusher.success)
-        self.assertEqual(build.Status.BUILT, self.image.status)
+        self.assertEqual(utils.Status.BUILT, self.image.status)
 
     @mock.patch.dict(os.environ, clear=True)
     @mock.patch('docker.APIClient')
     def test_build_image(self, mock_client):
         self.dc = mock_client
         push_queue = mock.Mock()
-        builder = build.BuildTask(self.conf, self.image, push_queue)
+        builder = tasks.BuildTask(self.conf, self.image, push_queue)
         builder.run()
 
         mock_client().build.assert_called_once_with(
@@ -179,7 +163,7 @@ class TasksTest(base.TestCase):
         push_queue = mock.Mock()
         self.conf.set_override('network_mode', 'bridge')
 
-        builder = build.BuildTask(self.conf, self.image, push_queue)
+        builder = tasks.BuildTask(self.conf, self.image, push_queue)
         builder.run()
 
         mock_client().build.assert_called_once_with(
@@ -199,7 +183,7 @@ class TasksTest(base.TestCase):
         }
         self.conf.set_override('build_args', build_args)
         push_queue = mock.Mock()
-        builder = build.BuildTask(self.conf, self.image, push_queue)
+        builder = tasks.BuildTask(self.conf, self.image, push_queue)
         builder.run()
 
         mock_client().build.assert_called_once_with(
@@ -218,7 +202,7 @@ class TasksTest(base.TestCase):
         build_args = {
             'http_proxy': 'http://FROM_ENV:8080',
         }
-        builder = build.BuildTask(self.conf, self.image, push_queue)
+        builder = tasks.BuildTask(self.conf, self.image, push_queue)
         builder.run()
 
         mock_client().build.assert_called_once_with(
@@ -239,7 +223,7 @@ class TasksTest(base.TestCase):
         self.conf.set_override('build_args', build_args)
 
         push_queue = mock.Mock()
-        builder = build.BuildTask(self.conf, self.image, push_queue)
+        builder = tasks.BuildTask(self.conf, self.image, push_queue)
         builder.run()
 
         mock_client().build.assert_called_once_with(
@@ -260,12 +244,12 @@ class TasksTest(base.TestCase):
             'enabled': True
         }
         push_queue = mock.Mock()
-        builder = build.BuildTask(self.conf, self.image, push_queue)
+        builder = tasks.BuildTask(self.conf, self.image, push_queue)
         mock_get.side_effect = requests.exceptions.Timeout
         get_result = builder.process_source(self.image, self.image.source)
 
         self.assertIsNone(get_result)
-        self.assertEqual(self.image.status, build.Status.ERROR)
+        self.assertEqual(self.image.status, utils.Status.ERROR)
         mock_get.assert_called_once_with(self.image.source['source'],
                                          timeout=120)
 
@@ -296,127 +280,15 @@ class TasksTest(base.TestCase):
                         'enabled': True}]:
             self.image.source = source
             push_queue = mock.Mock()
-            builder = build.BuildTask(self.conf, self.image, push_queue)
+            builder = tasks.BuildTask(self.conf, self.image, push_queue)
             get_result = builder.process_source(self.image, self.image.source)
-            self.assertEqual(self.image.status, build.Status.ERROR)
+            self.assertEqual(self.image.status, utils.Status.ERROR)
             self.assertFalse(builder.success)
             if source['type'] != 'local':
                 self.assertIsNone(get_result)
             else:
                 self.assertIsNotNone(get_result)
 
-    @mock.patch.dict(os.environ, clear=True)
-    @mock.patch('docker.APIClient')
-    def test_local_directory(self, mock_client):
-        tmpdir = tempfile.mkdtemp()
-        file_name = 'test.txt'
-        file_path = os.path.join(tmpdir, file_name)
-        saved_umask = os.umask(0o077)
-
-        try:
-            with open(file_path, 'w') as f:
-                f.write('Hello')
-
-            self.dc = mock_client
-            self.image.plugins = [{
-                'name': 'fake-image-base-plugin-test',
-                'type': 'local',
-                'enabled': True,
-                'source': tmpdir}
-                ]
-            push_queue = mock.Mock()
-            builder = build.BuildTask(self.conf, self.image, push_queue)
-            builder.run()
-            self.assertTrue(builder.success)
-
-        except IOError:
-            print('IOError')
-        else:
-            os.remove(file_path)
-        finally:
-            os.umask(saved_umask)
-            os.rmdir(tmpdir)
-
-    @mock.patch.dict(os.environ, clear=True)
-    @mock.patch('docker.APIClient')
-    def test_malicious_tar(self, mock_client):
-        tmpdir = tempfile.mkdtemp()
-        file_name = 'test.txt'
-        archive_name = 'my_archive.tar'
-        file_path = os.path.join(tmpdir, file_name)
-        archive_path = os.path.join(tmpdir, archive_name)
-        # Ensure the file is read/write by the creator only
-        saved_umask = os.umask(0o077)
-
-        try:
-            with open(file_path, 'w') as f:
-                f.write('Hello')
-
-            with tarfile.open(archive_path, 'w') as tar:
-                tar.add(file_path, arcname='../test.txt')
-
-            self.dc = mock_client
-            self.image.plugins = [{
-                'name': 'fake-image-base-plugin-test',
-                'type': 'local',
-                'enabled': True,
-                'source': archive_path}
-                ]
-
-            push_queue = mock.Mock()
-            builder = build.BuildTask(self.conf, self.image, push_queue)
-            builder.run()
-            self.assertFalse(builder.success)
-
-        except IOError:
-            print('IOError')
-        else:
-            os.remove(file_path)
-            os.remove(archive_path)
-        finally:
-            os.umask(saved_umask)
-            os.rmdir(tmpdir)
-
-    @mock.patch.dict(os.environ, clear=True)
-    @mock.patch('docker.APIClient')
-    def test_malicious_tar_gz(self, mock_client):
-        tmpdir = tempfile.mkdtemp()
-        file_name = 'test.txt'
-        archive_name = 'my_archive.tar.gz'
-        file_path = os.path.join(tmpdir, file_name)
-        archive_path = os.path.join(tmpdir, archive_name)
-        # Ensure the file is read/write by the creator only
-        saved_umask = os.umask(0o077)
-
-        try:
-            with open(file_path, 'w') as f:
-                f.write('Hello')
-
-            with tarfile.open(archive_path, 'w:gz') as tar:
-                tar.add(file_path, arcname='../test.txt')
-
-            self.dc = mock_client
-            self.image.plugins = [{
-                'name': 'fake-image-base-plugin-test',
-                'type': 'local',
-                'enabled': True,
-                'source': archive_path}
-                ]
-
-            push_queue = mock.Mock()
-            builder = build.BuildTask(self.conf, self.image, push_queue)
-            builder.run()
-            self.assertFalse(builder.success)
-
-        except IOError:
-            print('IOError')
-        else:
-            os.remove(file_path)
-            os.remove(archive_path)
-        finally:
-            os.umask(saved_umask)
-            os.rmdir(tmpdir)
-
     @mock.patch('os.path.exists')
     @mock.patch('os.utime')
     @mock.patch('shutil.rmtree')
@@ -431,12 +303,12 @@ class TasksTest(base.TestCase):
         self.image.path = "fake_image_path"
         mock_path_exists.return_value = True
         push_queue = mock.Mock()
-        builder = build.BuildTask(self.conf, self.image, push_queue)
+        builder = tasks.BuildTask(self.conf, self.image, push_queue)
         get_result = builder.process_source(self.image, self.image.source)
 
         mock_rmtree.assert_called_with(
             "fake_image_path/fake-image1-archive-fake-reference1")
-        self.assertEqual(self.image.status, build.Status.ERROR)
+        self.assertEqual(self.image.status, utils.Status.ERROR)
         self.assertFalse(builder.success)
         self.assertIsNone(get_result)
 
@@ -449,7 +321,7 @@ class TasksTest(base.TestCase):
         }
         self.imageChild.children.append(FAKE_IMAGE_CHILD_UNMATCHED)
         push_queue = mock.Mock()
-        builder = build.BuildTask(self.conf, self.imageChild, push_queue)
+        builder = tasks.BuildTask(self.conf, self.imageChild, push_queue)
         builder.success = True
         self.conf.push = FAKE_IMAGE_CHILD_UNMATCHED
         get_result = builder.followups
@@ -479,23 +351,15 @@ class KollaWorkerTest(base.TestCase):
         self.addCleanup(patcher.stop)
         self.mock_client = patcher.start()
 
-    def test_supported_base_type(self):
+    def test_supported_base_distro(self):
         build_base = ['centos', 'debian', 'ubuntu']
-        build_type = ['source', 'binary']
 
-        for base_distro, install_type in itertools.chain(
-                itertools.product(build_base, build_type)):
+        for base_distro in build_base:
             self.conf.set_override('base', base_distro)
-            if base_distro == 'debian' and install_type == 'binary':
-                self.conf.set_override('base_arch', 'x86_64')
-            self.conf.set_override('install_type', install_type)
             # should no exception raised
             build.KollaWorker(self.conf)
 
     def test_build_image_list_adds_plugins(self):
-
-        self.conf.set_override('install_type', 'source')
-
         kolla = build.KollaWorker(self.conf)
         kolla.setup_working_dir()
         kolla.find_dockerfiles()
@@ -521,8 +385,6 @@ class KollaWorkerTest(base.TestCase):
             self.fail('Can not find the expected neutron arista plugin')
 
     def test_build_image_list_skips_disabled_plugins(self):
-
-        self.conf.set_override('install_type', 'source')
         self.conf.set_override('enabled', False,
                                'neutron-base-plugin-networking-baremetal')
 
@@ -546,8 +408,6 @@ class KollaWorkerTest(base.TestCase):
 
     def test_build_image_list_plugin_parsing(self):
         """Ensure regex used to parse plugins adds them to the correct image"""
-        self.conf.set_override('install_type', 'source')
-
         kolla = build.KollaWorker(self.conf)
         kolla.setup_working_dir()
         kolla.find_dockerfiles()
@@ -563,27 +423,26 @@ class KollaWorkerTest(base.TestCase):
             self.fail('Expected to find the base image in this test')
 
     def test_set_time(self):
-        self.conf.set_override('install_type', 'source')
         kolla = build.KollaWorker(self.conf)
         kolla.setup_working_dir()
         kolla.set_time()
 
     def _get_matched_images(self, images):
         return [image for image in images
-                if image.status == build.Status.MATCHED]
+                if image.status == utils.Status.MATCHED]
 
     def test_skip_parents(self):
         self.conf.set_override('skip_parents', True)
         kolla = build.KollaWorker(self.conf)
         kolla.images = self.images[:2]
         for i in kolla.images:
-            i.status = build.Status.UNPROCESSED
+            i.status = utils.Status.UNPROCESSED
             if i.parent:
                 i.parent.children.append(i)
         kolla.filter_images()
 
-        self.assertEqual(build.Status.MATCHED, kolla.images[1].status)
-        self.assertEqual(build.Status.SKIPPED, kolla.images[1].parent.status)
+        self.assertEqual(utils.Status.MATCHED, kolla.images[1].status)
+        self.assertEqual(utils.Status.SKIPPED, kolla.images[1].parent.status)
 
     def test_skip_parents_regex(self):
         self.conf.set_override('regex', ['image-child'])
@@ -591,13 +450,13 @@ class KollaWorkerTest(base.TestCase):
         kolla = build.KollaWorker(self.conf)
         kolla.images = self.images[:2]
         for i in kolla.images:
-            i.status = build.Status.UNPROCESSED
+            i.status = utils.Status.UNPROCESSED
             if i.parent:
                 i.parent.children.append(i)
         kolla.filter_images()
 
-        self.assertEqual(build.Status.MATCHED, kolla.images[1].status)
-        self.assertEqual(build.Status.SKIPPED, kolla.images[1].parent.status)
+        self.assertEqual(utils.Status.MATCHED, kolla.images[1].status)
+        self.assertEqual(utils.Status.SKIPPED, kolla.images[1].parent.status)
 
     def test_skip_parents_match_grandchildren(self):
         self.conf.set_override('skip_parents', True)
@@ -607,14 +466,14 @@ class KollaWorkerTest(base.TestCase):
         self.images[1].children.append(image_grandchild)
         kolla.images = self.images[:2] + [image_grandchild]
         for i in kolla.images:
-            i.status = build.Status.UNPROCESSED
+            i.status = utils.Status.UNPROCESSED
             if i.parent:
                 i.parent.children.append(i)
         kolla.filter_images()
 
-        self.assertEqual(build.Status.MATCHED, kolla.images[2].status)
-        self.assertEqual(build.Status.SKIPPED, kolla.images[2].parent.status)
-        self.assertEqual(build.Status.SKIPPED, kolla.images[1].parent.status)
+        self.assertEqual(utils.Status.MATCHED, kolla.images[2].status)
+        self.assertEqual(utils.Status.SKIPPED, kolla.images[2].parent.status)
+        self.assertEqual(utils.Status.SKIPPED, kolla.images[1].parent.status)
 
     def test_skip_parents_match_grandchildren_regex(self):
         self.conf.set_override('regex', ['image-grandchild'])
@@ -625,27 +484,27 @@ class KollaWorkerTest(base.TestCase):
         self.images[1].children.append(image_grandchild)
         kolla.images = self.images[:2] + [image_grandchild]
         for i in kolla.images:
-            i.status = build.Status.UNPROCESSED
+            i.status = utils.Status.UNPROCESSED
             if i.parent:
                 i.parent.children.append(i)
         kolla.filter_images()
 
-        self.assertEqual(build.Status.MATCHED, kolla.images[2].status)
-        self.assertEqual(build.Status.SKIPPED, kolla.images[2].parent.status)
-        self.assertEqual(build.Status.SKIPPED, kolla.images[1].parent.status)
+        self.assertEqual(utils.Status.MATCHED, kolla.images[2].status)
+        self.assertEqual(utils.Status.SKIPPED, kolla.images[2].parent.status)
+        self.assertEqual(utils.Status.SKIPPED, kolla.images[1].parent.status)
 
-    @mock.patch.object(build.Image, 'in_docker_cache')
+    @mock.patch.object(Image, 'in_docker_cache')
     def test_skip_existing(self, mock_in_cache):
         mock_in_cache.side_effect = [True, False]
         self.conf.set_override('skip_existing', True)
         kolla = build.KollaWorker(self.conf)
         kolla.images = self.images[:2]
         for i in kolla.images:
-            i.status = build.Status.UNPROCESSED
+            i.status = utils.Status.UNPROCESSED
         kolla.filter_images()
 
-        self.assertEqual(build.Status.SKIPPED, kolla.images[0].status)
-        self.assertEqual(build.Status.MATCHED, kolla.images[1].status)
+        self.assertEqual(utils.Status.SKIPPED, kolla.images[0].status)
+        self.assertEqual(utils.Status.MATCHED, kolla.images[1].status)
 
     def test_without_profile(self):
         kolla = build.KollaWorker(self.conf)
@@ -663,7 +522,6 @@ class KollaWorkerTest(base.TestCase):
     def test_build_distro_python_version_debian(self):
         """check distro_python_version for Debian"""
         self.conf.set_override('base', 'debian')
-        self.conf.set_override('install_type', 'source')
         kolla = build.KollaWorker(self.conf)
         self.assertEqual('3.9', kolla.distro_python_version)
 
@@ -671,17 +529,11 @@ class KollaWorkerTest(base.TestCase):
         """check distro_python_version for Ubuntu"""
         self.conf.set_override('base', 'ubuntu')
         kolla = build.KollaWorker(self.conf)
-        self.assertEqual('3.8', kolla.distro_python_version)
+        self.assertEqual('3.10', kolla.distro_python_version)
 
     def test_build_distro_python_version_centos(self):
-        """check distro_python_version for CentOS Stream 8"""
-        self.conf.set_override('base', 'centos')
-        kolla = build.KollaWorker(self.conf)
-        self.assertEqual('3.6', kolla.distro_python_version)
-
-    def test_build_distro_python_version_centos9(self):
         """check distro_python_version for CentOS Stream 9"""
-        self.conf.set_override('base_tag', 'stream9')
+        self.conf.set_override('base', 'centos')
         kolla = build.KollaWorker(self.conf)
         self.assertEqual('3.9', kolla.distro_python_version)
 
@@ -694,7 +546,6 @@ class KollaWorkerTest(base.TestCase):
     def test_build_distro_package_manager_debian(self):
         """check distro_package_manager apt for debian"""
         self.conf.set_override('base', 'debian')
-        self.conf.set_override('install_type', 'source')
         kolla = build.KollaWorker(self.conf)
         self.assertEqual('apt', kolla.distro_package_manager)
 
@@ -713,7 +564,6 @@ class KollaWorkerTest(base.TestCase):
     def test_base_package_type_debian(self):
         """check base_package_type deb for debian"""
         self.conf.set_override('base', 'debian')
-        self.conf.set_override('install_type', 'source')
         kolla = build.KollaWorker(self.conf)
         self.assertEqual('deb', kolla.base_package_type)
 
@@ -755,10 +605,10 @@ class KollaWorkerTest(base.TestCase):
     def test_summary(self):
         kolla = build.KollaWorker(self.conf)
         kolla.images = self.images
-        kolla.image_statuses_good['good'] = build.Status.BUILT
-        kolla.image_statuses_bad['bad'] = build.Status.ERROR
-        kolla.image_statuses_allowed_to_fail['bad2'] = build.Status.ERROR
-        kolla.image_statuses_unmatched['unmatched'] = build.Status.UNMATCHED
+        kolla.image_statuses_good['good'] = utils.Status.BUILT
+        kolla.image_statuses_bad['bad'] = utils.Status.ERROR
+        kolla.image_statuses_allowed_to_fail['bad2'] = utils.Status.ERROR
+        kolla.image_statuses_unmatched['unmatched'] = utils.Status.UNMATCHED
         results = kolla.summary()
         self.assertEqual('error', results['failed'][0]['status'])  # bad
         self.assertEqual('error', results['failed'][1]['status'])  # bad2
